==> okteta-14.11.80.tar.xz: okteta-14.11.80/kasten/core/io/filesystem/bytearrayrawfileloadthread.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008-2009,2011-2012 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearrayrawfileloadthread.h"

// lib
#include "bytearraydocument.h"
// Kasten core
#include <person.h>
// Okteta core
#include <piecetablebytearraymodel.h>
// KF5
#include <KLocalizedString>
// Qt
#include <QtCore/QCoreApplication>
#include <QtCore/QDataStream>
#include <QtCore/QFile>
// C++
#include <limits>


namespace Kasten
{

void ByteArrayRawFileLoadThread::run()
{
    const qint64 fileSize = mFile->size();

    // check if the file content can be addressed with Okteta::Address
    const Okteta::Address maxAddress = std::numeric_limits<Okteta::Address>::max();

    bool success = ( fileSize <= maxAddress );

    if( success )
    {
        // allocate working memory
        QByteArray data;
        data.resize( fileSize );
        bool success = ( data.size() == fileSize );

        if( success )
        {
            QDataStream inStream( mFile );
            inStream.readRawData( data.data(), fileSize );

            success = ( inStream.status() == QDataStream::Ok );

            if( success )
            {
                Okteta::PieceTableByteArrayModel* byteArray = new Okteta::PieceTableByteArrayModel( data );
                byteArray->setModified( false );

                mDocument = new ByteArrayDocument( byteArray, i18nc("destination of the byte array", "Loaded from file.") );
                mDocument->setOwner( Person::createEgo() );
                // TODO: make PieceTableByteArrayModel a child by constructor argument parent
                byteArray->moveToThread( QCoreApplication::instance()->thread() );
                mDocument->moveToThread( QCoreApplication::instance()->thread() );
            }
            else
                mErrorString = mFile->errorString();
        }
        else
            mErrorString = i18n( "There is not enough free working memory to load this file." );
    }
    else
        mErrorString = i18n( "Support to load files larger than 2 GiB has not yet been implemented." );

    if( ! success )
        mDocument = 0;

    emit documentRead( mDocument );
}

ByteArrayRawFileLoadThread::~ByteArrayRawFileLoadThread() {}

}

==> okteta-15.04.3.tar.xz: okteta-15.04.3/kasten/core/io/filesystem/bytearrayrawfileloadthread.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008-2009,2011-2012 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearrayrawfileloadthread.h"

// lib
#include "bytearraydocument.h"
// Kasten core
#include <kasten/person.h>
// Okteta core
#include <okteta/piecetablebytearraymodel.h>
// KF5
#include <KLocalizedString>
// Qt
#include <QCoreApplication>
#include <QDataStream>
#include <QFile>
// C++
#include <limits>


namespace Kasten
{

void ByteArrayRawFileLoadThread::run()
{
    const qint64 fileSize = mFile->size();

    // check if the file content can be addressed with Okteta::Address
    const Okteta::Address maxAddress = std::numeric_limits<Okteta::Address>::max();

    bool success = ( fileSize <= maxAddress );

    if( success )
    {
        // allocate working memory
        QByteArray data;
        data.resize( fileSize );
        bool success = ( data.size() == fileSize );

        if( success )
        {
            QDataStream inStream( mFile );
            inStream.readRawData( data.data(), fileSize );

            success = ( inStream.status() == QDataStream::Ok );

            if( success )
            {
                Okteta::PieceTableByteArrayModel* byteArray = new Okteta::PieceTableByteArrayModel( data );
                byteArray->setModified( false );

                mDocument = new ByteArrayDocument( byteArray, i18nc("destination of the byte array", "Loaded from file.") );
                mDocument->setOwner( Person::createEgo() );
                // TODO: make PieceTableByteArrayModel a child by constructor argument parent
                byteArray->moveToThread( QCoreApplication::instance()->thread() );
                mDocument->moveToThread( QCoreApplication::instance()->thread() );
            }
            else
                mErrorString = mFile->errorString();
        }
        else
            mErrorString = i18n( "There is not enough free working memory to load this file." );
    }
    else
        mErrorString = i18n( "Support to load files larger than 2 GiB has not yet been implemented." );

    if( ! success )
        mDocument = 0;

    emit documentRead( mDocument );
}

ByteArrayRawFileLoadThread::~ByteArrayRawFileLoadThread() {}

}
